==> ejc-report-impl-3.0.0-20201110.023302-17-sources.jar: com/ejianc/foundation/report/bean/TableEntity.java <==
package com.ejianc.foundation.report.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 数据表
 * 
 * @author guoming
 */
@TableName("ejc_report_tbl")
public class TableEntity extends BaseEntity {

	private static final long serialVersionUID = 5542455641344731158L;
	
	@TableField(value = "code")
	private String code; //报表编码
	
	@TableField(value = "table_name")
	private String tableName;// 报表名称

	@TableField(value = "index_name")
	private String indexName; //对应的索引库
	
	@TableField(value = "dataset_id")
	private Long datasetId; //对应的数据集

	@TableField(value = "condition_json")
	private String conditionJson; //报表配置的筛选条件

	//报表排序条件
	@TableField(value = "order_item_json")
	private String orderItemJson;

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public String getIndexName() {
		return indexName;
	}

	public void setIndexName(String indexName) {
		this.indexName = indexName;
	}

	public Long getDatasetId() {
		return datasetId;
	}

	public void setDatasetId(Long datasetId) {
		this.datasetId = datasetId;
	}

	public String getConditionJson() {
		return conditionJson;
	}

	public void setConditionJson(String conditionJson) {
		this.conditionJson = conditionJson;
	}

	public String getOrderItemJson() {
		return orderItemJson;
	}

	public void setOrderItemJson(String orderItemJson) {
		this.orderItemJson = orderItemJson;
	}
}

==> ejc-report-impl-3.0.1-20210726.013329-2-sources.jar: com/ejianc/foundation/report/bean/TableEntity.java <==
package com.ejianc.foundation.report.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 数据表
 * 
 * @author guoming
 */
@TableName("ejc_report_tbl")
public class TableEntity extends BaseEntity {

	private static final long serialVersionUID = 5542455641344731158L;
	
	@TableField(value = "code")
	private String code; //报表编码
	
	@TableField(value = "table_name")
	private String tableName;// 报表名称

	@TableField(value = "index_name")
	private String indexName; //对应的索引库
	
	@TableField(value = "dataset_id")
	private String datasetIds; //对应的数据集

	@TableField(value = "dataset_names")
	private String datasetNames; //对应的数据集

	@TableField(value = "condition_json")
	private String conditionJson; //报表配置的筛选条件

	//报表排序条件
	@TableField(value = "order_item_json")
	private String orderItemJson;

	//参数Url
	@TableField(value = "param_url")
	private String paramUrl;

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public String getIndexName() {
		return indexName;
	}

	public void setIndexName(String indexName) {
		this.indexName = indexName;
	}

	public String getConditionJson() {
		return conditionJson;
	}

	public void setConditionJson(String conditionJson) {
		this.conditionJson = conditionJson;
	}

	public String getOrderItemJson() {
		return orderItemJson;
	}

	public void setOrderItemJson(String orderItemJson) {
		this.orderItemJson = orderItemJson;
	}

	public String getDatasetIds() {
		return datasetIds;
	}

	public void setDatasetIds(String datasetIds) {
		this.datasetIds = datasetIds;
	}

	public String getDatasetNames() {
		return datasetNames;
	}

	public void setDatasetNames(String datasetNames) {
		this.datasetNames = datasetNames;
	}

	public String getParamUrl() {
		return paramUrl;
	}

	public void setParamUrl(String paramUrl) {
		this.paramUrl = paramUrl;
	}
}
